ApnsPushConnector class

Inheritance
Implemented types

Constructors

ApnsPushConnector()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDisabledByUser → ValueNotifier<bool?>
finalinherited
onIosSettingsRegistered → Stream<IosNotificationSettings>
no setterinherited
providerType → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldPresent ↔ WillPresentHandler?
Handler that returns true/false to decide if push alert should be displayed when in foreground. Returning true will delay onMessage callback until user actually clicks on it
getter/setter pairinherited
token → ValueNotifier<String?>
finalinherited

Methods

configure({MessageHandler? onMessage, MessageHandler? onLaunch, MessageHandler? onResume, MessageHandler? onBackgroundMessage, FirebaseOptions? options}) → Future<void>
Configures callbacks for supported message situations. It should be called as soon as app is launch or you won't get the onLaunch callback
override
configureApns({ApnsMessageHandler? onMessage, ApnsMessageHandler? onLaunch, ApnsMessageHandler? onResume, ApnsMessageHandler? onBackgroundMessage}) → void
Sets up MessageHandler for incoming messages.
inherited
dispose() → void
inherited
getAuthorizationStatus() → Future<ApnsAuthorizationStatus>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestNotificationPermissions([IosNotificationSettings iosSettings = const IosNotificationSettings()]) → Future<bool>
inherited
setNotificationCategories(List<UNNotificationCategory> categories) → Future<void>
https://developer.apple.com/documentation/usernotifications/declaring_your_actionable_notification_types
inherited
toString() → String
A string representation of this object.
inherited
unregister() → Future<void>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited